@@ -34,24 +34,22 @@
  #include  <common/gfal_common_plugin.h>
 
 
- int gfal_posix_internal_chmod(const char* path, mode_t mode){
-	 GError* tmp_err=NULL;
-	 gfal2_context_t handle;
-	 int res= -1;
+ int gfal_posix_internal_chmod(const char* path, mode_t mode)
+{
+    GError* tmp_err = NULL;
+    gfal2_context_t handle;
+    int res = -1;
 
-	if((handle = gfal_posix_instance()) == NULL){
-		errno = EIO;
-		return -1;
-	}
+    if ((handle = gfal_posix_instance()) == NULL) {
+        errno = EIO;
+        return -1;
+    }
 
     res = gfal2_chmod(handle, path, mode, &tmp_err);
-	if(tmp_err){
-		gfal_posix_register_internal_error(handle, "[gfal_chmod]", tmp_err);
-		errno = tmp_err->code;
-	}
-	return res;
-
- }
-
-
+    if (tmp_err) {
+        gfal_posix_register_internal_error(handle, "[gfal_chmod]", tmp_err);
+        errno = tmp_err->code;
+    }
+    return res;
 
+}
