@@ -38,18 +38,19 @@
 #include "gfal_posix_internal.h"
 
 
-int gfal_posix_internal_close(int fd){
-	GError* tmp_err=NULL;
-	int ret = -1;
-	gfal2_context_t handle;
-	if((handle = gfal_posix_instance()) == NULL){
-		errno = EIO;
-		return -1;
-	}
+int gfal_posix_internal_close(int fd)
+{
+    GError* tmp_err = NULL;
+    int ret = -1;
+    gfal2_context_t handle;
+    if ((handle = gfal_posix_instance()) == NULL) {
+        errno = EIO;
+        return -1;
+    }
     ret = gfal2_close(handle, fd, &tmp_err);
-	if(tmp_err){
-		gfal_posix_register_internal_error(handle, "[gfal_close]", tmp_err);
-		errno = tmp_err->code;
-	}
-	return ret;
+    if (tmp_err) {
+        gfal_posix_register_internal_error(handle, "[gfal_close]", tmp_err);
+        errno = tmp_err->code;
+    }
+    return ret;
 }
