@@ -38,22 +38,21 @@
 #include "gfal_posix_internal.h"
 
 
-ssize_t gfal_posix_internal_unlink(const char* path){
-	gfal2_context_t handle;
-	GError* tmp_err = NULL;
-	ssize_t ret = -1;
+ssize_t gfal_posix_internal_unlink(const char* path)
+{
+    gfal2_context_t handle;
+    GError* tmp_err = NULL;
+    ssize_t ret = -1;
 
-	if( (handle = gfal_posix_instance()) == NULL){
-		errno = EIO;
-		return -1;
-	}
+    if ((handle = gfal_posix_instance()) == NULL) {
+        errno = EIO;
+        return -1;
+    }
 
     ret = gfal2_unlink(handle, path, &tmp_err);
-	if(tmp_err){ // error reported
-		gfal_posix_register_internal_error(handle, "[gfal_unlink]", tmp_err);
-		errno = tmp_err->code;
-	}
-	return ret;
+    if (tmp_err) { // error reported
+        gfal_posix_register_internal_error(handle, "[gfal_unlink]", tmp_err);
+        errno = tmp_err->code;
+    }
+    return ret;
 }
-
-
