@@ -1,3 +1,21 @@
+/*
+* Copyright @ CERN, 2014.
+*
+* Licensed under the Apache License, Version 2.0 (the "License");
+* you may not use this file except in compliance with the License.
+* You may obtain a copy of the License at
+*
+*    http://www.apache.org/licenses/LICENSE-2.0
+*
+* Unless required by applicable law or agreed to in writing, software
+* distributed under the License is distributed on an "AS IS" BASIS,
+* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+* See the License for the specific language governing permissions and
+* limitations under the License.
+*/
+#include <string>
+#include <vector>
+
 #include "gridftp_filecopy.h"
 #include "gridftpwrapper.h"
 #include "gridftp_namespace.h"
@@ -6,9 +24,8 @@
 #include <globus_ftp_client_throughput_plugin.h>
 #include <checksums/checksums.h>
 
-extern const char * gridftp_enable_udt;
 
-static const Glib::Quark GSIFTP_BULK_DOMAIN("GridFTP::Filecopy");
+static const GQuark GSIFTP_BULK_DOMAIN = g_quark_from_static_string("GridFTP::Filecopy");
 
 
 struct GridFTPBulkData {
@@ -57,8 +74,6 @@ struct GridFTPBulkPerformance {
     std::string source, destination;
     gfalt_params_t params;
     bool ipv6;
-    gfalt_monitor_func monitor_func;
-    void* monitor_data;
     time_t start_time;
 
     globus_ftp_client_plugin_t* plugin;
@@ -102,7 +117,7 @@ static void gridftp_pipeline_callback(globus_ftp_client_handle_t * handle, char
 
     // Skip pairs marked as failed
     while (data->index < data->nbfiles && data->errn[data->index]) {
-        gfal_log(GFAL_VERBOSE_DEBUG,
+        gfal2_log(G_LOG_LEVEL_DEBUG,
                 "Skipping pair %d as marked failed with %d", data->index,
                 data->errn[data->index]);
         data->index++;
@@ -114,13 +129,13 @@ static void gridftp_pipeline_callback(globus_ftp_client_handle_t * handle, char
         *dest_url = (char*)data->dsts[data->index];
         data->started[data->index] = true;
 
-        gfal_log(GFAL_VERBOSE_VERBOSE, "Providing pair %s => %s", *source_url, *dest_url);
+        gfal2_log(G_LOG_LEVEL_INFO, "Providing pair %s => %s", *source_url, *dest_url);
     }
     else {
         *source_url = NULL;
         *dest_url = NULL;
 
-        gfal_log(GFAL_VERBOSE_VERBOSE, "No more pairs to give");
+        gfal2_log(G_LOG_LEVEL_INFO, "No more pairs to give");
     }
 }
 
@@ -163,17 +178,15 @@ void gridftp_bulk_throughput_cb(void *user_specific,
     GridFTPBulkPerformance* pd;
     globus_ftp_client_throughput_plugin_get_user_specific(original->plugin, (void**)(&pd));
 
-    if (pd->monitor_func) {
-        gfalt_hook_transfer_plugin_t hook;
-        hook.bytes_transfered = bytes;
-        hook.average_baudrate = (size_t) avg_throughput;
-        hook.instant_baudrate = (size_t) instantaneous_throughput;
-        hook.transfer_time = (time(NULL) - pd->start_time);
+    gfalt_hook_transfer_plugin_t hook;
+    hook.bytes_transfered = bytes;
+    hook.average_baudrate = (size_t) avg_throughput;
+    hook.instant_baudrate = (size_t) instantaneous_throughput;
+    hook.transfer_time = (time(NULL) - pd->start_time);
 
-        gfalt_transfer_status_t state = gfalt_transfer_status_create(&hook);
-        pd->monitor_func(state, pd->source.c_str(), pd->destination.c_str(), pd->monitor_data);
-        gfalt_transfer_status_delete(state);
-    }
+    gfalt_transfer_status_t state = gfalt_transfer_status_create(&hook);
+    plugin_trigger_monitor(pd->params, state, pd->source.c_str(), pd->destination.c_str());
+    gfalt_transfer_status_delete(state);
 }
 
 
@@ -208,14 +221,12 @@ int gridftp_pipeline_transfer(plugin_handle plugin_data,
         gfal2_context_t context, bool udt, GridFTPBulkData* pairs, GError** op_error)
 {
     GridFTPModule* gsiftp = static_cast<GridFTPModule*>(plugin_data);
-    GridFTPSession sess(
-            gsiftp->get_session_factory()->gfal_globus_ftp_take_handle(
-                    gridftp_hostname_from_url(pairs->srcs[0])));
+    GridFTPSessionHandler handler(gsiftp->get_session_factory(), pairs->srcs[0]);
 
     globus_ftp_client_plugin_t throughput_plugin;
     globus_ftp_client_handle_t ftp_handle;
     globus_ftp_client_operationattr_t ftp_operation_attr;
-    globus_ftp_client_handleattr_t* ftp_handle_attr = sess.get_ftp_handle_attr();
+    globus_ftp_client_handleattr_t* ftp_handle_attr = handler.get_ftp_client_handleattr();
 
     // First viable pair goes with the globus call
     pairs->index = 0;
@@ -228,9 +239,7 @@ int gridftp_pipeline_transfer(plugin_handle plugin_data,
 
     GridFTPBulkPerformance perf;
     perf.params = pairs->params;
-    perf.ipv6 = gfal2_get_opt_boolean_with_default(context, GRIDFTP_CONFIG_GROUP, gridftp_ipv6_config, false);
-    perf.monitor_func = gfalt_get_monitor_callback(pairs->params, NULL);
-    perf.monitor_data = gfalt_get_user_data(pairs->params, NULL);
+    perf.ipv6 = gfal2_get_opt_boolean_with_default(context, GRIDFTP_CONFIG_GROUP, GRIDFTP_CONFIG_IPV6, false);
     perf.plugin = &throughput_plugin;
 
     globus_ftp_client_throughput_plugin_init(&throughput_plugin,
@@ -243,7 +252,7 @@ int gridftp_pipeline_transfer(plugin_handle plugin_data,
     globus_ftp_client_handleattr_set_pipeline(ftp_handle_attr, 0, gridftp_pipeline_callback, pairs);
     globus_ftp_client_handle_init(&ftp_handle, ftp_handle_attr);
     globus_ftp_client_operationattr_init(&ftp_operation_attr);
-    globus_ftp_client_operationattr_copy(&ftp_operation_attr, sess.get_op_attr_ftp());
+    globus_ftp_client_operationattr_copy(&ftp_operation_attr, handler.get_ftp_client_operationattr());
     globus_ftp_client_operationattr_set_mode(&ftp_operation_attr, GLOBUS_FTP_CONTROL_MODE_EXTENDED_BLOCK);
     globus_ftp_client_operationattr_set_delayed_pasv(&ftp_operation_attr, GLOBUS_FALSE);
 
@@ -281,7 +290,7 @@ int gridftp_pipeline_transfer(plugin_handle plugin_data,
                 pairs->srcs[pairs->index], &ftp_operation_attr,
                 pairs->dsts[pairs->index], &ftp_operation_attr,
                 GLOBUS_NULL, gridftp_done_callback, pairs);
-        gfal_globus_check_result("gridftp_bulk_copy", globus_return);
+        gfal_globus_check_result(GSIFTP_BULK_DOMAIN, globus_return);
 
         globus_mutex_lock(&pairs->lock);
 
@@ -303,7 +312,7 @@ int gridftp_pipeline_transfer(plugin_handle plugin_data,
             char *err_buffer;
             int err_code = gfal_globus_error_convert(pairs->error, &err_buffer);
             if (err_code) {
-                gfal_log(GFAL_VERBOSE_VERBOSE, "Bulk transfer failed with %s", err_buffer);
+                gfal2_log(G_LOG_LEVEL_INFO, "Bulk transfer failed with %s", err_buffer);
                 gfal2_set_error(op_error, GSIFTP_BULK_DOMAIN, err_code, __func__, "%s", err_buffer);
                 res = -1;
                 g_free(err_buffer);
@@ -315,8 +324,8 @@ int gridftp_pipeline_transfer(plugin_handle plugin_data,
         }
     }
     catch (const Gfal::CoreException& e) {
-        gfal_log(GFAL_VERBOSE_NORMAL, "Bulk transfer failed with %s", e.what().c_str());
-        gfal2_set_error(op_error, e.domain(), e.code(), __func__, "%s", e.what().c_str());
+        gfal2_log(G_LOG_LEVEL_MESSAGE, "Bulk transfer failed with %s", e.what());
+        gfal2_set_error(op_error, e.domain(), e.code(), __func__, "%s", e.what());
         res = -1;
     }
 
@@ -405,6 +414,7 @@ int gridftp_bulk_prepare_destination(plugin_handle plugin_data,
         gfal2_context_t context, GridFTPBulkData* pairs, GError** file_errors)
 {
     int nfailed = 0;
+    std::vector<std::string> created_parents;
 
     for (size_t i = 0; i < pairs->nbfiles; ++i) {
         // May have failed when preparing the source!
@@ -416,14 +426,28 @@ int gridftp_bulk_prepare_destination(plugin_handle plugin_data,
             }
             else {
                 try {
-                    gridftp_filecopy_delete_existing((GridFTPModule*) plugin_data,
-                            pairs->params, pairs->dsts[i]);
-                    gridftp_create_parent_copy((GridFTPModule*) plugin_data,
-                            pairs->params, pairs->dsts[i]);
+                    const char* slash = strrchr(pairs->dsts[i], '/');
+                    std::string parent;
+                    if (slash)
+                        parent.assign(pairs->dsts[i], 0, slash - pairs->dsts[i]);
+
+                    gridftp_filecopy_delete_existing(
+                            (GridFTPModule*) plugin_data, pairs->params,
+                            pairs->dsts[i]);
+
+                    if (slash &&
+                        std::find(created_parents.begin(), created_parents.end(), parent) != created_parents.end()) {
+                        gfal2_log(G_LOG_LEVEL_INFO, "Skip mkdir of %s", parent.c_str());
+                    }
+                    else {
+                        gridftp_create_parent_copy((GridFTPModule*) plugin_data,
+                                pairs->params, pairs->dsts[i]);
+                        created_parents.push_back(parent);
+                    }
                 }
                 catch (const Gfal::TransferException& e) {
                     gfal2_set_error(&(file_errors[i]), GSIFTP_BULK_DOMAIN, e.code(),
-                            __func__, "%s", e.what().c_str());
+                            __func__, "%s", e.what());
                     pairs->errn[i] = e.code();
                 }
             }
@@ -532,7 +556,7 @@ int gridftp_bulk_copy(plugin_handle plugin_data, gfal2_context_t context, gfalt_
         size_t nbfiles, const char* const * srcs, const char* const * dsts,
         const char* const * checksums, GError** op_error, GError*** file_errors)
 {
-    gfal_log(GFAL_VERBOSE_TRACE, "-> %s", __func__);
+    gfal2_log(G_LOG_LEVEL_DEBUG, "-> %s", __func__);
 
     if (nbfiles == 0 || srcs == NULL || dsts == NULL) {
         gfal2_set_error(op_error, GSIFTP_BULK_DOMAIN, EINVAL, __func__, "Invalid parameters");
@@ -560,7 +584,7 @@ int gridftp_bulk_copy(plugin_handle plugin_data, gfal2_context_t context, gfalt_
     int transfer_ret = -1;
     if (!gfal2_is_canceled(context)) {
         bool udt = gfal2_get_opt_boolean_with_default(context,
-                GRIDFTP_CONFIG_GROUP, gridftp_enable_udt, false);
+                GRIDFTP_CONFIG_GROUP, GRIDFTP_CONFIG_TRANSFER_UDT, false);
 
         transfer_ret = gridftp_pipeline_transfer(plugin_data, context, udt, &pairs, op_error);
         // If UDT was tried and it failed, give it another shot
@@ -572,7 +596,7 @@ int gridftp_bulk_copy(plugin_handle plugin_data, gfal2_context_t context, gfalt_
             g_error_free(*op_error);
             *op_error = NULL;
 
-            gfal_log(GFAL_VERBOSE_VERBOSE, "UDT transfer failed! Disabling and retrying...");
+            gfal2_log(G_LOG_LEVEL_INFO, "UDT transfer failed! Disabling and retrying...");
             transfer_ret = gridftp_pipeline_transfer(plugin_data, context, udt, &pairs, op_error);
         }
     }
@@ -584,7 +608,7 @@ int gridftp_bulk_copy(plugin_handle plugin_data, gfal2_context_t context, gfalt_
         total_failed += gridftp_bulk_close(plugin_data, context, &pairs, *file_errors);
 
     // Done
-    gfal_log(GFAL_VERBOSE_TRACE, "<- %s", __func__);
+    gfal2_log(G_LOG_LEVEL_DEBUG, "<- %s", __func__);
     gfal2_end_scope_cancel(context);
     return -total_failed;
 }
