@@ -5,12 +5,12 @@
 #include <iostream>
 #include "../gridftpwrapper.h"
 
-class GridftpStreamBuffer: public std::streambuf {
+class GridFTPStreamBuffer: public std::streambuf {
 protected:
     GridFTPStreamState* gstream;
     char buffer[4096];
 
-    Glib::Quark quark;
+    GQuark quark;
 
     ssize_t fetch_more() {
         ssize_t rsize = gridftp_read_stream(quark, gstream, buffer, sizeof(buffer) - 1, false);
@@ -19,12 +19,12 @@ protected:
     }
 
 public:
-    GridftpStreamBuffer(GridFTPStreamState* gsiftp_stream, const Glib::Quark& quark):
+    GridFTPStreamBuffer(GridFTPStreamState* gsiftp_stream, GQuark quark):
         gstream(gsiftp_stream), quark(quark) {
         fetch_more();
     }
 
-    virtual ~GridftpStreamBuffer() {
+    virtual ~GridFTPStreamBuffer() {
     }
 
     int_type underflow() {
