@@ -22,6 +22,7 @@
 
 #include "gridftp_namespace.h"
 #include "gridftp_filecopy.h"
+#include "gridftp_plugin.h"
 
 #include <checksums/checksums.h>
 #include <uri/gfal_uri.h>
@@ -37,9 +38,9 @@
 #include <exceptions/gerror_to_cpp.h>
 #include <exceptions/cpp_to_gerror.hpp>
 
-static Glib::Quark GFAL_GRIDFTP_SCOPE_FILECOPY("GridFTPFileCopyModule::FileCopy");
+static const GQuark GFAL_GRIDFTP_SCOPE_FILECOPY = g_quark_from_string("GridFTPFileCopyModule::FileCopy");
 
-static Glib::Quark GFAL_GRIDFTP_DOMAIN_GSIFTP("GSIFTP");
+static const GQuark GFAL_GRIDFTP_DOMAIN_GSIFTP = g_quark_from_string("GSIFTP");
 
 /*IPv6 compatible lookup*/
 static
@@ -101,21 +102,15 @@ std::string return_hostname(const std::string &uri, gboolean use_ipv6)
 {
     GError* error = NULL;
     gfal_uri parsed;
-    gfal_parse_uri(uri.c_str(), &parsed, &error);
+    gfal2_parse_uri(uri.c_str(), &parsed, &error);
     if (error)
-        throw Glib::Error(error);
+        throw Gfal::CoreException(error);
     std::ostringstream str;
     str << lookup_host(parsed.domain, use_ipv6) << ":" << parsed.port;
     return str.str();
 }
 
 
-const char * gridftp_checksum_transfer_config   = "COPY_CHECKSUM_TYPE";
-const char * gridftp_perf_marker_timeout_config = "PERF_MARKER_TIMEOUT";
-const char * gridftp_skip_transfer_config       = "SKIP_SOURCE_CHECKSUM";
-const char * gridftp_enable_udt                 = "ENABLE_UDT";
-
-
 // return 1 if deleted something
 int gridftp_filecopy_delete_existing(GridFTPModule* module,
         gfalt_params_t params, const char * url)
@@ -124,10 +119,10 @@ int gridftp_filecopy_delete_existing(GridFTPModule* module,
     bool exist = module->exists(url);
     if (exist) {
         if (replace) {
-            gfal_log(GFAL_VERBOSE_TRACE,
+            gfal2_log(G_LOG_LEVEL_DEBUG,
                     " File %s already exist, delete it for override ....", url);
             module->unlink(url);
-            gfal_log(GFAL_VERBOSE_TRACE,
+            gfal2_log(G_LOG_LEVEL_DEBUG,
                     " File %s deleted with success, proceed to copy ....", url);
             plugin_trigger_event(params, GFAL_GRIDFTP_DOMAIN_GSIFTP,
                     GFAL_EVENT_DESTINATION, GFAL_EVENT_OVERWRITE_DESTINATION,
@@ -138,9 +133,8 @@ int gridftp_filecopy_delete_existing(GridFTPModule* module,
             char err_buff[GFAL_ERRMSG_LEN];
             snprintf(err_buff, GFAL_ERRMSG_LEN,
                     " Destination already exist %s, Cancel", url);
-            throw Gfal::TransferException(GFAL_GRIDFTP_SCOPE_FILECOPY,
-                    err_buff,
-                    EEXIST, GFALT_ERROR_DESTINATION, GFALT_ERROR_EXISTS);
+            throw Gfal::TransferException(GFAL_GRIDFTP_SCOPE_FILECOPY, EEXIST,
+                    err_buff, GFALT_ERROR_DESTINATION, GFALT_ERROR_EXISTS);
         }
     }
     return 0;
@@ -153,7 +147,7 @@ void gridftp_create_parent_copy(GridFTPModule* module, gfalt_params_t params,
 {
     const gboolean create_parent = gfalt_get_create_parent_dir(params, NULL);
     if (create_parent) {
-        gfal_log(GFAL_VERBOSE_TRACE, " -> [gridftp_create_parent_copy]");
+        gfal2_log(G_LOG_LEVEL_DEBUG, " -> [gridftp_create_parent_copy]");
         char current_uri[GFAL_URL_MAX_LEN];
         g_strlcpy(current_uri, gridftp_url, GFAL_URL_MAX_LEN);
         const size_t s_uri = strlen(current_uri);
@@ -172,10 +166,11 @@ void gridftp_create_parent_copy(GridFTPModule* module, gfalt_params_t params,
 
             try {
                 module->stat(current_uri, &st);
-                if (!S_ISDIR(st.st_mode))
-                    throw Gfal::TransferException(GFAL_GRIDFTP_SCOPE_FILECOPY,
+                if (!S_ISDIR(st.st_mode)) {
+                    throw Gfal::TransferException(GFAL_GRIDFTP_SCOPE_FILECOPY, ENOTDIR,
                             "The parent of the destination file exists, but it is not a directory",
-                            ENOTDIR, GFALT_ERROR_DESTINATION);
+                            GFALT_ERROR_DESTINATION);
+                }
                 return;
             }
             catch (Gfal::CoreException& e) {
@@ -184,17 +179,16 @@ void gridftp_create_parent_copy(GridFTPModule* module, gfalt_params_t params,
             }
 
             GError* tmp_err = NULL;
-            (void) gfal2_mkdir_rec(module->get_session_factory()->get_handle(),
+            (void) gfal2_mkdir_rec(module->get_session_factory()->get_gfal2_context(),
                     current_uri, 0755, &tmp_err);
             Gfal::gerror_to_cpp(&tmp_err);
         }
         else {
-            throw Gfal::TransferException(GFAL_GRIDFTP_SCOPE_FILECOPY,
-                    "Impossible to create directory " + std::string(current_uri)
-                            + " : invalid path",
-                    EINVAL, GFALT_ERROR_DESTINATION);
+            throw Gfal::TransferException(GFAL_GRIDFTP_SCOPE_FILECOPY, EINVAL,
+                    "Impossible to create directory " + std::string(current_uri) + " : invalid path",
+                    GFALT_ERROR_DESTINATION);
         }
-        gfal_log(GFAL_VERBOSE_TRACE, " [gridftp_create_parent_copy] <-");
+        gfal2_log(G_LOG_LEVEL_DEBUG, " [gridftp_create_parent_copy] <-");
     }
 }
 
@@ -203,40 +197,20 @@ void gsiftp_3rd_callback(void* user_args, globus_gass_copy_handle_t* handle, glo
 //
 // Performance callback object
 // contain the performance callback parameter
-// an the auto cancel logic on performance callback inaticity
-struct CallbackHandler{
-
-    CallbackHandler(gfal2_context_t context, gfalt_params_t params,
-            GridFTPRequestState* req, const char* src, const char* dst,
-            size_t src_size) :
-            args(NULL)
-    {
-        GError * tmp_err = NULL;
-        gfalt_monitor_func callback = gfalt_get_monitor_callback(params,
-                &tmp_err);
-        Gfal::gerror_to_cpp(&tmp_err);
-        gpointer user_args = gfalt_get_user_data(params, &tmp_err);
-        Gfal::gerror_to_cpp(&tmp_err);
-
-        if (callback) {
-            args = new callback_args(context, callback, user_args, src, dst,
-                    req, src_size);
-        }
-    }
+// and the auto cancel logic on performance callback inactivity
+struct CallbackHandler {
 
     static void* func_timer(void* v)
     {
-        callback_args* args = (callback_args*) v;
+        CallbackHandler* args = (CallbackHandler*) v;
         while (time(NULL) < args->timeout_time) {
             if (pthread_setcancelstate(PTHREAD_CANCEL_ENABLE, NULL) != 0) {
-                gfal_log(GFAL_VERBOSE_TRACE,
-                        " thread setcancelstate error, interrupt performance marker timer");
+                gfal2_log(G_LOG_LEVEL_DEBUG, "thread setcancelstate error, interrupt performance marker timer");
                 return NULL;
             }
             usleep(500000);
             if (pthread_setcancelstate(PTHREAD_CANCEL_DISABLE, NULL) != 0) {
-                gfal_log(GFAL_VERBOSE_TRACE,
-                        " thread setcancelstate error, interrupt performance marker timer");
+                gfal2_log(G_LOG_LEVEL_DEBUG, "thread setcancelstate error, interrupt performance marker timer");
                 return NULL;
             }
         }
@@ -245,74 +219,70 @@ struct CallbackHandler{
         msg << "Transfer canceled because the gsiftp performance marker timeout of "
             << args->timeout_value
             << " seconds has been exceeded, or all performance markers during that period indicated zero bytes transferred";
-        args->req->cancel_operation_async(GFAL_GRIDFTP_SCOPE_FILECOPY, msg.str());
 
-        return NULL;
+        try {
+            args->req->cancel(GFAL_GRIDFTP_SCOPE_FILECOPY, msg.str());
+            fprintf(stderr, "ALL COOL\n");
+        }
+        catch (Gfal::CoreException& e) {
+            gfal2_log(G_LOG_LEVEL_INFO,
+                    "Exception while cancelling on performance marker timeout: %s",
+                    e.what());
+        }
+        catch (...) {
+            gfal2_log(G_LOG_LEVEL_INFO,
+                    "Unknown exception while cancelling on performance marker timeout");
+        }
+
+        pthread_exit(NULL);
+    }
+
+    CallbackHandler(gfal2_context_t context, gfalt_params_t params,
+            GridFTPRequestState* req, const char* src, const char* dst,
+            size_t src_size):
+                params(params), req(req), src(src), dst(dst), start_time(0), timeout_value(0),
+                timeout_time(0), timer_pthread(0), source_size(src_size)
+    {
+        timeout_value = gfal2_get_opt_integer_with_default(context,
+                    GRIDFTP_CONFIG_GROUP, GRIDFTP_CONFIG_TRANSFER_PERF_TIMEOUT, 180);
+
+        start_time = time(NULL);
+
+        if (timeout_value > 0) {
+            timeout_time = start_time + timeout_value;
+            pthread_create(&timer_pthread, NULL, CallbackHandler::func_timer, this);
+        }
+
+        globus_gass_copy_register_performance_cb(
+                req->handler->get_gass_copy_handle(), gsiftp_3rd_callback,
+                (gpointer) this);
     }
 
     virtual ~CallbackHandler()
     {
-        if (args) {
-            delete args;
+        if (timeout_value > 0) {
+            pthread_cancel(timer_pthread);
+            pthread_join(timer_pthread, NULL);
         }
+        globus_gass_copy_register_performance_cb(req->handler->get_gass_copy_handle(), NULL, NULL);
     }
 
-    struct callback_args {
-        callback_args(gfal2_context_t context,
-                const gfalt_monitor_func mcallback, gpointer muser_args,
-                const char* msrc, const char* mdst, GridFTPRequestState* mreq,
-                size_t src_size) :
-                callback(mcallback), user_args(muser_args), req(mreq), src(
-                        msrc), dst(mdst), start_time(time(NULL)), timeout_value(
-                        gfal2_get_opt_integer_with_default(context,
-                                GRIDFTP_CONFIG_GROUP,
-                                gridftp_perf_marker_timeout_config, 180)), timeout_time(
-                        time(NULL) + timeout_value), timer_pthread()
-        {
-            Glib::RWLock::ReaderLock l(req->mux_req_state);
-            globus_gass_copy_register_performance_cb(
-                    req->sess->get_gass_handle(), gsiftp_3rd_callback,
-                    (gpointer) this);
-
-            if (timeout_value > 0) {
-                pthread_create(&timer_pthread, NULL,
-                        CallbackHandler::func_timer, this);
-            }
-
-            source_size = src_size;
-        }
-
-        virtual ~callback_args()
-        {
-            if (timeout_value > 0) {
-                void * res;
-                pthread_cancel(timer_pthread);
-                pthread_join(timer_pthread, &res);
-            }
-            Glib::RWLock::ReaderLock l(req->mux_req_state);
-            globus_gass_copy_register_performance_cb(
-                    req->sess->get_gass_handle(), NULL, NULL);
-        }
-
-        gfalt_monitor_func callback;
-        gpointer user_args;
-        GridFTPRequestState* req;
-        const char* src;
-        const char* dst;
-        time_t start_time;
-        int timeout_value;
-        time_t timeout_time;
-        pthread_t timer_pthread;
-        globus_off_t source_size;
-    }*args;
+    gfalt_params_t params;
+    GridFTPRequestState* req;
+    const char* src;
+    const char* dst;
+    time_t start_time;
+    int timeout_value;
+    time_t timeout_time;
+    pthread_t timer_pthread;
+    globus_off_t source_size;
 };
 
 
 void gsiftp_3rd_callback(void* user_args, globus_gass_copy_handle_t* handle,
         globus_off_t total_bytes, float throughput, float avg_throughput)
 {
-    CallbackHandler::callback_args * args =
-            (CallbackHandler::callback_args *) user_args;
+    CallbackHandler* args = (CallbackHandler*)user_args;
 
     gfalt_hook_transfer_plugin_t hook;
     hook.bytes_transfered = total_bytes;
@@ -321,26 +291,26 @@ void gsiftp_3rd_callback(void* user_args, globus_gass_copy_handle_t* handle,
     hook.transfer_time = (time(NULL) - args->start_time);
 
     gfalt_transfer_status_t state = gfalt_transfer_status_create(&hook);
-    args->callback(state, args->src, args->dst, args->user_args);
+    plugin_trigger_monitor(args->params, state, args->src, args->dst);
     gfalt_transfer_status_delete(state);
 
-    // If throughput != 0, or the file has been already sent, reset timer callback
-    // [LCGUTIL-440] Some endpoints calculate the checksum before closing, so we will
-    //               get throughput = 0 for a while, and the transfer should not fail
-    if (throughput != 0.0
-            || (args->source_size > 0 && args->source_size <= total_bytes)) {
-        GridFTPRequestState* req = args->req;
-        Glib::RWLock::ReaderLock l(req->mux_req_state);
-        if (args->timeout_value > 0) {
-            gfal_log(GFAL_VERBOSE_TRACE,
-                    "Performance marker received, re-arm timer");
-            args->timeout_time = time(NULL) + args->timeout_value;
+    if (args->timeout_time > 0) {
+        // If throughput != 0, or the file has been already sent, reset timer callback
+        // [LCGUTIL-440] Some endpoints calculate the checksum before closing, so we will
+        //               get throughput = 0 for a while, and the transfer should not fail
+        if (throughput != 0.0 || (args->source_size > 0 && args->source_size <= total_bytes)) {
+            //GridFTPRequestState* req = args->req;
+            //Glib::RWLock::ReaderLock l(req->mux_req_state);
+            if (args->timeout_value > 0) {
+                gfal2_log(G_LOG_LEVEL_DEBUG, "Performance marker received, re-arm timer");
+                args->timeout_time = time(NULL) + args->timeout_value;
+            }
+        }
+        // Otherwise, do not reset and notify
+        else {
+            gfal2_log(G_LOG_LEVEL_MESSAGE,
+                    "Performance marker received, but throughput is 0. Not resetting timeout!");
         }
-    }
-    // Otherwise, do not reset and notify
-    else {
-        gfal_log(GFAL_VERBOSE_NORMAL,
-                "Performance marker received, but throughput is 0. Not resetting timeout!");
     }
 }
 
@@ -350,37 +320,22 @@ void gridftp_do_copy(GridFTPModule* module, GridFTPFactory* factory,
         gfalt_params_t params, const char* src, const char* dst,
         GridFTPRequestState& req, time_t timeout)
 {
-    /*
-     This will not work with Castor
-     struct stat src_stat;
+    GassCopyAttrHandler gass_attr_src(req.handler->get_ftp_client_operationattr());
+    GassCopyAttrHandler gass_attr_dst(req.handler->get_ftp_client_operationattr());
+    CallbackHandler callback_handler(factory->get_gfal2_context(), params, &req, src, dst, 0);
 
-     try {
-     module->stat(src, &src_stat);
-     }
-     catch (...) {
-     src_stat.st_size = 0;
-     }
-     */
-
-    GridFTPSession* sess = req.sess.get();
-
-    Gass_attr_handler gass_attr_src(sess->get_op_attr_ftp());
-    Gass_attr_handler gass_attr_dst(sess->get_op_attr_ftp());
-    CallbackHandler callback_handler(factory->get_handle(), params, &req, src,
-            dst, 0);
-
-    req.start();
-    gfal_log(GFAL_VERBOSE_TRACE,
+    gfal2_log(G_LOG_LEVEL_DEBUG,
             "   [GridFTPFileCopyModule::filecopy] start gridftp transfer %s -> %s",
             src, dst);
-    GridFTPOperationCanceler canceler(factory->get_handle(), &req);
-    globus_result_t res = globus_gass_copy_register_url_to_url(
-            sess->get_gass_handle(), (char*) src, &(gass_attr_src.attr_gass),
-            (char*) dst, &(gass_attr_dst.attr_gass),
-            globus_gass_basic_client_callback, &req);
 
-    gfal_globus_check_result("GridFTPFileCopyModule::filecopy", res);
-    req.wait_callback(GFAL_GRIDFTP_SCOPE_FILECOPY, timeout);
+    globus_result_t res = globus_gass_copy_register_url_to_url(
+            req.handler->get_gass_copy_handle(),
+            (char*) src, &(gass_attr_src.attr_gass),
+            (char*) dst, &(gass_attr_dst.attr_gass),
+            globus_gass_client_done_callback, &req);
+
+    gfal_globus_check_result(GFAL_GRIDFTP_SCOPE_FILECOPY, res);
+    req.wait(GFAL_GRIDFTP_SCOPE_FILECOPY, timeout);
 }
 
 
@@ -391,6 +346,8 @@ int gridftp_filecopy_copy_file_internal(GridFTPModule* module,
 {
     GError * tmp_err = NULL;
 
+    gboolean is_strict_mode = gfalt_get_strict_copy_mode(params, NULL);
+
     const time_t timeout = gfalt_get_timeout(params, &tmp_err);
     Gfal::gerror_to_cpp(&tmp_err);
 
@@ -399,35 +356,32 @@ int gridftp_filecopy_copy_file_internal(GridFTPModule* module,
     const guint64 tcp_buffer_size = gfalt_get_tcp_buffer_size(params, &tmp_err);
     Gfal::gerror_to_cpp(&tmp_err);
 
-    if (gfalt_get_strict_copy_mode(params, NULL) == false) {
+    if (!is_strict_mode) {
         // If 1, the destination was deleted. So the parent directory is there!
         if (gridftp_filecopy_delete_existing(module, params, dst) == 0)
             gridftp_create_parent_copy(module, params, dst);
     }
 
-    GridFTPRequestState req(
-            factory->gfal_globus_ftp_take_handle(
-                    gridftp_hostname_from_url(src)), true,
-            GRIDFTP_REQUEST_GASS);
-    GridFTPSession* sess = req.sess.get();
+    GridFTPSessionHandler handler(factory, src);
+    GridFTPRequestState req(&handler, GRIDFTP_REQUEST_GASS);
 
-    sess->set_nb_stream(nbstream);
-    gfal_log(GFAL_VERBOSE_TRACE,
+    handler.session->set_nb_streams(nbstream);
+    gfal2_log(G_LOG_LEVEL_DEBUG,
             "   [GridFTPFileCopyModule::filecopy] setup gsiftp number of streams to %d",
             nbstream);
-    sess->set_tcp_buffer_size(tcp_buffer_size);
-    gfal_log(GFAL_VERBOSE_TRACE,
+    handler.session->set_tcp_buffer_size(tcp_buffer_size);
+    gfal2_log(G_LOG_LEVEL_DEBUG,
             "   [GridFTPFileCopyModule::filecopy] setup gsiftp buffer size to %d",
             tcp_buffer_size);
 
-    gboolean enable_udt_transfers = gfal2_get_opt_boolean(factory->get_handle(),
-    GRIDFTP_CONFIG_GROUP, gridftp_enable_udt, NULL);
+    gboolean enable_udt_transfers = gfal2_get_opt_boolean(factory->get_gfal2_context(),
+            GRIDFTP_CONFIG_GROUP, GRIDFTP_CONFIG_TRANSFER_UDT, NULL);
 
     if (enable_udt_transfers) {
-        gfal_log(GFAL_VERBOSE_VERBOSE, "Trying UDT transfer");
+        gfal2_log(G_LOG_LEVEL_INFO, "Trying UDT transfer");
         plugin_trigger_event(params, GFAL_GRIDFTP_DOMAIN_GSIFTP, GFAL_EVENT_NONE,
                 g_quark_from_static_string("UDT:ENABLE"), "Trying UDT");
-        sess->enable_udt();
+        handler.session->set_udt(true);
     }
 
     try {
@@ -435,17 +389,16 @@ int gridftp_filecopy_copy_file_internal(GridFTPModule* module,
     }
     catch (Gfal::CoreException& e) {
         // Try again if the failure was related to udt
-        if (e.what().find("udt driver not whitelisted")
-                != Glib::ustring::npos) {
-            gfal_log(GFAL_VERBOSE_VERBOSE,
+        if (e.what_str().find("udt driver not whitelisted") != std::string::npos) {
+            gfal2_log(G_LOG_LEVEL_INFO,
                     "UDT transfer failed! Disabling and retrying...");
 
             plugin_trigger_event(params, GFAL_GRIDFTP_DOMAIN_GSIFTP, GFAL_EVENT_NONE,
                     g_quark_from_static_string("UDT:DISABLE"),
                     "UDT failed. Falling back to default mode: %s",
-                    e.what().c_str());
+                    e.what());
 
-            sess->disable_udt();
+            handler.session->set_udt(false);
             gridftp_do_copy(module, factory, params, src, dst, req, timeout);
         }
         // Else, rethrow
@@ -469,8 +422,7 @@ void gridftp_checksum_transfer_verify(const char * src_chk, const char* dst_chk,
         if (gfal_compare_checksums(src_chk, dst_chk, GFAL_URL_MAX_LEN) != 0) {
             ss << "SRC and DST checksum are different. Source: " << src_chk
                     << " Destination: " << dst_chk;
-            throw Gfal::CoreException(GFAL_GRIDFTP_SCOPE_FILECOPY, ss.str(),
-            EIO);
+            throw Gfal::CoreException(GFAL_GRIDFTP_SCOPE_FILECOPY, EIO, ss.str());
         }
     }
     else {
@@ -479,16 +431,14 @@ void gridftp_checksum_transfer_verify(const char * src_chk, const char* dst_chk,
                         GFAL_URL_MAX_LEN) != 0) {
             ss << "USER_DEFINE and SRC checksums are different. "
                     << user_defined_chk << " != " << src_chk;
-            throw Gfal::CoreException(GFAL_GRIDFTP_SCOPE_FILECOPY, ss.str(),
-            EIO);
+            throw Gfal::CoreException(GFAL_GRIDFTP_SCOPE_FILECOPY, EIO, ss.str());
         }
 
         if (gfal_compare_checksums(dst_chk, user_defined_chk, GFAL_URL_MAX_LEN)
                 != 0) {
             ss << "USER_DEFINE and DST checksums are different. "
                     << user_defined_chk << " != " << dst_chk;
-            throw Gfal::CoreException(GFAL_GRIDFTP_SCOPE_FILECOPY, ss.str(),
-            EIO);
+            throw Gfal::CoreException(GFAL_GRIDFTP_SCOPE_FILECOPY, EIO, ss.str());
         }
     }
 }
@@ -499,13 +449,13 @@ void GridFTPModule::autoCleanFileCopy(gfalt_params_t params,
         GError* checked_error, const char* dst)
 {
     if (checked_error && checked_error->code != EEXIST) {
-        gfal_log(GFAL_VERBOSE_TRACE,
+        gfal2_log(G_LOG_LEVEL_DEBUG,
                 "\t\tError in transfer, clean destination file %s ", dst);
         try {
             this->unlink(dst);
         }
         catch (...) {
-            gfal_log(GFAL_VERBOSE_TRACE, "\t\tFailure in cleaning ...");
+            gfal2_log(G_LOG_LEVEL_DEBUG, "\t\tFailure in cleaning ...");
         }
     }
 }
@@ -519,13 +469,14 @@ void GridFTPModule::filecopy(gfalt_params_t params, const char* src,
     char checksum_src[GFAL_URL_MAX_LEN] = { 0 };
     char checksum_dst[GFAL_URL_MAX_LEN] = { 0 };
 
-    gboolean checksum_check = gfalt_get_checksum_check(params, NULL);
+    gboolean checksum_check =
+            gfalt_get_checksum_check(params, NULL) && !gfalt_get_strict_copy_mode(params, NULL);
     gboolean skip_source_checksum = gfal2_get_opt_boolean(
-            _handle_factory->get_handle(),
-            GRIDFTP_CONFIG_GROUP, gridftp_skip_transfer_config,
+            _handle_factory->get_gfal2_context(),
+            GRIDFTP_CONFIG_GROUP, GRIDFTP_CONFIG_TRANSFER_SKIP_CHECKSUM,
             NULL);
-    gboolean use_ipv6 = gfal2_get_opt_boolean(_handle_factory->get_handle(),
-    GRIDFTP_CONFIG_GROUP, gridftp_ipv6_config,
+    gboolean use_ipv6 = gfal2_get_opt_boolean(_handle_factory->get_gfal2_context(),
+    GRIDFTP_CONFIG_GROUP, GRIDFTP_CONFIG_IPV6,
     NULL);
 
     if (checksum_check) {
@@ -539,8 +490,8 @@ void GridFTPModule::filecopy(gfalt_params_t params, const char* src,
             char *default_checksum_type;
 
             default_checksum_type = gfal2_get_opt_string(
-                    _handle_factory->get_handle(),
-                    GRIDFTP_CONFIG_GROUP, gridftp_checksum_transfer_config,
+                    _handle_factory->get_gfal2_context(),
+                    GRIDFTP_CONFIG_GROUP, GRIDFTP_CONFIG_TRANSFER_CHECKSUM,
                     &get_default_error);
             Gfal::gerror_to_cpp(&get_default_error);
 
@@ -548,11 +499,11 @@ void GridFTPModule::filecopy(gfalt_params_t params, const char* src,
                     sizeof(checksum_type));
             g_free(default_checksum_type);
 
-            gfal_log(GFAL_VERBOSE_TRACE,
+            gfal2_log(G_LOG_LEVEL_DEBUG,
                     "\t\tNo user defined checksum, fetch the default one from configuration");
         }
 
-        gfal_log(GFAL_VERBOSE_DEBUG,
+        gfal2_log(G_LOG_LEVEL_DEBUG,
                 "\t\tChecksum Algorithm for transfer verification %s",
                 checksum_type);
     }
@@ -578,14 +529,14 @@ void GridFTPModule::filecopy(gfalt_params_t params, const char* src,
                         checksum_type, checksum_src);
             }
         }
-        catch (const Glib::Error &e) {
-            throw Gfal::TransferException(e.domain(), e.what(), e.code(),
+        catch (const Gfal::CoreException &e) {
+            throw Gfal::TransferException(e.domain(), e.code(), e.what(),
                     GFALT_ERROR_SOURCE);
         }
         catch (...) {
-            throw Gfal::TransferException(GFAL_GRIDFTP_DOMAIN_GSIFTP,
+            throw Gfal::TransferException(GFAL_GRIDFTP_DOMAIN_GSIFTP, EIO,
                     "Undefined Exception caught while getting the source checksum!!",
-                    EIO, GFALT_ERROR_SOURCE);
+                    GFALT_ERROR_SOURCE);
         }
     }
 
@@ -597,20 +548,19 @@ void GridFTPModule::filecopy(gfalt_params_t params, const char* src,
                 return_hostname(src, use_ipv6).c_str(), src,
                 return_hostname(dst, use_ipv6).c_str(), dst);
         try {
-            gridftp_filecopy_copy_file_internal(this, _handle_factory, params,
-                    src, dst);
+            gridftp_filecopy_copy_file_internal(this, _handle_factory, params, src, dst);
         }
         catch (Gfal::TransferException & e) {
             throw;
         }
-        catch (Glib::Error & e) {
+        catch (const Gfal::CoreException & e) {
             autoCleanFileCopy(params, transfer_error, dst);
-            throw Gfal::TransferException(e.domain(), e.what(), e.code(),
+            throw Gfal::TransferException(e.domain(), e.code(), e.what(),
                     GFALT_ERROR_TRANSFER);
         }
         catch (std::exception & e) {
             autoCleanFileCopy(params, transfer_error, dst);
-            throw Gfal::TransferException(GFAL_GRIDFTP_DOMAIN_GSIFTP, e.what(), EIO,
+            throw Gfal::TransferException(GFAL_GRIDFTP_DOMAIN_GSIFTP, EIO, e.what(),
                     GFALT_ERROR_TRANSFER, "UNEXPECTED");
         }
         catch (...) {
@@ -636,13 +586,13 @@ void GridFTPModule::filecopy(gfalt_params_t params, const char* src,
             gridftp_checksum_transfer_verify(checksum_src, checksum_dst,
                     checksum_user_defined);
         }
-        catch (Glib::Error & e) {
-            throw Gfal::TransferException(e.domain(), e.what(), e.code(),
+        catch (const Gfal::CoreException& e) {
+            throw Gfal::TransferException(e.domain(), e.code(), e.what(),
                     GFALT_ERROR_TRANSFER, GFALT_ERROR_CHECKSUM);
         }
         catch (...) {
-            throw Gfal::TransferException(GFAL_GRIDFTP_DOMAIN_GSIFTP,
-                    "Unexpected exception", EIO, GFALT_ERROR_TRANSFER);
+            throw Gfal::TransferException(GFAL_GRIDFTP_DOMAIN_GSIFTP, EIO,
+                    "Unexpected exception", GFALT_ERROR_TRANSFER);
         }
 
         plugin_trigger_event(params, GFAL_GRIDFTP_DOMAIN_GSIFTP,
@@ -663,12 +613,11 @@ extern "C" int gridftp_plugin_filecopy(plugin_handle handle, gfal2_context_t con
 
     GError * tmp_err = NULL;
     int ret = -1;
-    gfal_log(GFAL_VERBOSE_TRACE, "  -> [gridftp_plugin_filecopy]");
+    gfal2_log(G_LOG_LEVEL_DEBUG, "  -> [gridftp_plugin_filecopy]");
     CPP_GERROR_TRY
-                (static_cast<GridFTPModule*>(handle))->filecopy(params, src,
-                        dst);
-                ret = 0;
-            CPP_GERROR_CATCH(&tmp_err);
-    gfal_log(GFAL_VERBOSE_TRACE, "  [gridftp_plugin_filecopy]<-");
+        (static_cast<GridFTPModule*>(handle))->filecopy(params, src, dst);
+        ret = 0;
+    CPP_GERROR_CATCH(&tmp_err);
+    gfal2_log(G_LOG_LEVEL_DEBUG, "  [gridftp_plugin_filecopy]<-");
     G_RETURN_ERR(ret, tmp_err, err);
 }
