@@ -8,15 +8,12 @@
 
 
 struct PerfCallbackData {
+    gfalt_params_t     params;
+
     std::string        source;
     std::string        destination;
-    gfalt_monitor_func externalCallback;
-    void*              externalData;
-
-    PerfCallbackData(const std::string& src, const std::string& dst,
-                     gfalt_monitor_func callback, void* udata):
-         source(src), destination(dst),
-         externalCallback(callback), externalData(udata)
+    PerfCallbackData(gfalt_params_t params, const std::string& src, const std::string& dst):
+         params(params), source(src), destination(dst)
     {
     }
 };
@@ -102,13 +99,13 @@ static int gfal_http_copy_overwrite(plugin_handle plugin_data,
             return -1;
         }
 
-        gfal_log(GFAL_VERBOSE_DEBUG,
+        gfal2_log(G_LOG_LEVEL_DEBUG,
                  "File %s deleted with success (overwrite set)", dst);
         plugin_trigger_event(params, http_plugin_domain, GFAL_EVENT_DESTINATION,
                              GFAL_EVENT_OVERWRITE_DESTINATION, "Deleted %s", dst);
     }
     else if (exists == 0) {
-        gfal_log(GFAL_VERBOSE_DEBUG, "Destination does not exist");
+        gfal2_log(G_LOG_LEVEL_DEBUG, "Destination does not exist");
     }
     else if (exists < 0) {
         gfalt_propagate_prefixed_error(err, nestedError, __func__, GFALT_ERROR_DESTINATION, GFALT_ERROR_OVERWRITE);
@@ -167,7 +164,7 @@ static int gfal_http_copy_make_parent(plugin_handle plugin_data,
             gfalt_propagate_prefixed_error(err, nestedError, __func__, GFALT_ERROR_DESTINATION, GFALT_ERROR_PARENT);
             return -1;
         }
-        gfal_log(GFAL_VERBOSE_TRACE,
+        gfal2_log(G_LOG_LEVEL_DEBUG,
                  "[%s] Created parent directory %s", __func__, parent);
         return 0;
     }
@@ -214,7 +211,7 @@ static int gfal_http_copy_checksum(gfal2_context_t context,
             return -1;
         }
         else if (checksum_value[0]) {
-            gfal_log(GFAL_VERBOSE_TRACE,
+            gfal2_log(G_LOG_LEVEL_DEBUG,
                      "[%s] Source and user-defined %s match: %s",
                      __func__, checksum_type, checksum_value);
         }
@@ -236,7 +233,7 @@ static int gfal_http_copy_checksum(gfal2_context_t context,
             return -1;
         }
 
-        gfal_log(GFAL_VERBOSE_TRACE,
+        gfal2_log(G_LOG_LEVEL_DEBUG,
                  "[%s] Source and destination %s match: %s",
                  __func__, checksum_type, src_checksum);
     }
@@ -247,7 +244,7 @@ static int gfal_http_copy_checksum(gfal2_context_t context,
 static void gfal_http_3rdcopy_perfcallback(const Davix::PerformanceData& perfData, void* data)
 {
     PerfCallbackData* pdata = static_cast<PerfCallbackData*>(data);
-    if (pdata && pdata->externalCallback)
+    if (pdata)
     {
         gfalt_hook_transfer_plugin_t hook;
 
@@ -257,9 +254,8 @@ static void gfal_http_3rdcopy_perfcallback(const Davix::PerformanceData& perfDat
         hook.transfer_time    = perfData.absElapsed();
 
         gfalt_transfer_status_t state = gfalt_transfer_status_create(&hook);
-        pdata->externalCallback(state,
-                pdata->source.c_str(), pdata->destination.c_str(),
-                pdata->externalData);
+        plugin_trigger_monitor(pdata->params, state,
+                pdata->source.c_str(), pdata->destination.c_str());
         gfalt_transfer_status_delete(state);
     }
 }
@@ -272,17 +268,17 @@ static int gfal_http_copy_cleanup(plugin_handle plugin_data, const char* dst, GE
     if ((*err)->code != EEXIST) {
         if (gfal_http_unlinkG(plugin_data, dst, &unlink_err) != 0) {
             if (unlink_err->code != ENOENT) {
-                gfal_log(GFAL_VERBOSE_VERBOSE,
+                gfal2_log(G_LOG_LEVEL_INFO,
                          "When trying to clean the destination: %s", unlink_err->message);
             }
             g_error_free(unlink_err);
         }
         else {
-            gfal_log(GFAL_VERBOSE_DEBUG, "Destination file removed");
+            gfal2_log(G_LOG_LEVEL_DEBUG, "Destination file removed");
         }
     }
     else {
-        gfal_log(GFAL_VERBOSE_DEBUG, "The transfer failed because the file exists. Do not clean!");
+        gfal2_log(G_LOG_LEVEL_DEBUG, "The transfer failed because the file exists. Do not clean!");
     }
     return -1;
 }
@@ -317,16 +313,14 @@ static void gfal_http_third_party_copy(GfalHttpPluginData* davix,
         gfalt_params_t params,
         GError** err)
 {
-    gfal_log(GFAL_VERBOSE_VERBOSE, "Performing a HTTP third party copy");
+    gfal2_log(G_LOG_LEVEL_INFO, "Performing a HTTP third party copy");
 
     PerfCallbackData perfCallbackData(
-            src, dst,
-            gfalt_get_monitor_callback(params, NULL),
-            gfalt_get_user_data(params, NULL)
+            params, src, dst
     );
 
     std::string canonical_dst = get_canonical_uri(dst);
-    gfal_log(GFAL_VERBOSE_VERBOSE, "Normalize destination to %s", canonical_dst.c_str());
+    gfal2_log(G_LOG_LEVEL_INFO, "Normalize destination to %s", canonical_dst.c_str());
 
     Davix::Uri src_uri(src);
     Davix::Uri dst_uri(canonical_dst);
@@ -353,24 +347,19 @@ struct HttpStreamProvider {
     const char *source, *destination;
 
     gfal2_context_t context;
+    gfalt_params_t params;
     int source_fd;
     time_t start, last_update;
     dav_ssize_t read_instant;
     gfalt_hook_transfer_plugin_t perf;
 
-    gfalt_monitor_func perf_callback;
-    void* perf_callback_data;
-
     HttpStreamProvider(const char* source, const char* destination,
             gfal2_context_t context, int source_fd, gfalt_params_t params):
         source(source), destination(destination),
-        context(context), source_fd(source_fd), start(time(NULL)),
+        context(context), params(params), source_fd(source_fd), start(time(NULL)),
         last_update(start), read_instant(0)
     {
         memset(&perf, 0, sizeof(perf));
-
-        perf_callback = gfalt_get_monitor_callback(params, NULL);
-        perf_callback_data = gfalt_get_user_data(params, NULL);
     }
 };
 
@@ -407,11 +396,9 @@ static dav_ssize_t gfal_http_streamed_provider(void *userdata,
             data->last_update = now;
             data->read_instant = 0;
 
-            if (data->perf_callback) {
-                gfalt_transfer_status_t state = gfalt_transfer_status_create(&data->perf);
-                data->perf_callback(state, data->source, data->destination, data->perf_callback_data);
-                gfalt_transfer_status_delete(state);
-            }
+            gfalt_transfer_status_t state = gfalt_transfer_status_create(&data->perf);
+            plugin_trigger_monitor(data->params, state, data->source, data->destination);
+            gfalt_transfer_status_delete(state);
         }
     }
 
@@ -428,7 +415,7 @@ static void gfal_http_streamed_copy(gfal2_context_t context,
         gfalt_params_t params,
         GError** err)
 {
-    gfal_log(GFAL_VERBOSE_VERBOSE, "Performing a HTTP streamed copy");
+    gfal2_log(G_LOG_LEVEL_INFO, "Performing a HTTP streamed copy");
     GError *nested_err = NULL;
 
     struct stat src_stat;
@@ -480,7 +467,7 @@ static void gfal_http_streamed_copy(gfal2_context_t context,
         http2gliberr(err, request.getRequestCode(), __func__, "Failed to PUT the file");
     }
 
-    gfal_log(GFAL_VERBOSE_VERBOSE, "HTTP code %d", request.getRequestCode());
+    gfal2_log(G_LOG_LEVEL_INFO, "HTTP code %d", request.getRequestCode());
 }
 
 
@@ -518,8 +505,8 @@ int gfal_http_copy(plugin_handle plugin_data, gfal2_context_t context,
     strip_3rd_from_url(src_full, src, sizeof(src));
     strip_3rd_from_url(dst_full, dst, sizeof(dst));
 
-    gfal_log(GFAL_VERBOSE_VERBOSE, "Using source: %s", src);
-    gfal_log(GFAL_VERBOSE_VERBOSE, "Using destination: %s", dst);
+    gfal2_log(G_LOG_LEVEL_INFO, "Using source: %s", src);
+    gfal2_log(G_LOG_LEVEL_INFO, "Using destination: %s", dst);
 
     // When this flag is not set, the plugin should handle overwriting,
     // parent directory creation,...
