@@ -68,6 +68,17 @@ static void lfc_plugin_set_lfc_env(struct lfc_ops* ops, const char* var_name,
 }
 
 
+const char* lfc_plugin_get_lfc_env(struct lfc_ops* ops, const char* var_name)
+{
+    if (ops->get_env) {
+        return ops->get_env(var_name);
+    }
+    else {
+        return g_getenv(var_name);
+    }
+}
+
+
 int lfc_configure_environment(struct lfc_ops * ops, const char* host, GError** err)
 {
     GError * tmp_err=NULL;
@@ -96,7 +107,7 @@ int lfc_configure_environment(struct lfc_ops * ops, const char* host, GError** e
                         value= v1 =gfal2_get_opt_string(ops->handle, plugin_group, tab_envar_name[i], &tmp_err);
                     }
                     if(!tmp_err){
-                        gfal_log(GFAL_VERBOSE_TRACE, "lfc plugin : setup env var value %s to %s", tab_envar_name[i],value);
+                        gfal2_log(G_LOG_LEVEL_DEBUG, "lfc plugin : setup env var value %s to %s", tab_envar_name[i],value);
                         lfc_plugin_set_lfc_env(ops, tab_envar_name[i],value);
                         g_free(v1);
                     }else{
@@ -110,7 +121,7 @@ int lfc_configure_environment(struct lfc_ops * ops, const char* host, GError** e
                     if(!tmp_err){
                         char v_str[20];
                         snprintf(v_str,20, "%d",v2);
-                        gfal_log(GFAL_VERBOSE_TRACE, "lfc plugin : setup env var value %s to %d",tab_envar_name[i],v2);
+                        gfal2_log(G_LOG_LEVEL_DEBUG, "lfc plugin : setup env var value %s to %d",tab_envar_name[i],v2);
                         lfc_plugin_set_lfc_env(ops, tab_envar_name[i],v_str);
                     }else{
                         ret = -1;
@@ -131,13 +142,13 @@ int lfc_configure_environment(struct lfc_ops * ops, const char* host, GError** e
     gchar* ucert = gfal2_get_opt_string(ops->handle, "X509", "CERT", NULL);
     gchar* ukey = gfal2_get_opt_string(ops->handle, "X509", "KEY", NULL);
     if (ucert && ukey) {
-        gfal_log(GFAL_VERBOSE_TRACE, "lfc plugin : using certificate %s", ucert);
-        gfal_log(GFAL_VERBOSE_TRACE, "lfc plugin : using private key %s", ukey);
+        gfal2_log(G_LOG_LEVEL_DEBUG, "lfc plugin : using certificate %s", ucert);
+        gfal2_log(G_LOG_LEVEL_DEBUG, "lfc plugin : using private key %s", ukey);
         lfc_plugin_set_lfc_env(ops, "X509_USER_CERT", ucert);
         lfc_plugin_set_lfc_env(ops, "X509_USER_KEY", ukey);
     }
     else if (ucert) {
-        gfal_log(GFAL_VERBOSE_TRACE, "lfc plugin : using proxy %s", ucert);
+        gfal2_log(G_LOG_LEVEL_DEBUG, "lfc plugin : using proxy %s", ucert);
         lfc_plugin_set_lfc_env(ops, "X509_USER_PROXY", ucert);
     }
     g_free(ucert);
@@ -320,6 +331,7 @@ struct lfc_ops* gfal_load_lfc(const char* name, GError** err){
 
     if(lib_handle) {
         lfc_sym->set_env = dlsym(lib_handle, "lfc_setenv");
+        lfc_sym->get_env = dlsym(lib_handle, "lfc_getenv");
         dlclose(lib_handle);
     }
     else {
