@@ -37,14 +37,7 @@ static int validate_turls(int n_results, gfal_srm_result** resu,
     for (i = 0; i < n_results && !failed; ++i) {
         const char* turl = (*resu)[i].turl;
 
-        // Never ever accept file, even if it was asked for
-        if (strncmp("file:", turl, 5) == 0) {
-            failed = -1;
-            gfal2_set_error(tmp_err, gfal2_get_plugin_srm_quark(), EBADMSG, __func__,
-                    "file:// is not a valid turl");
-            break;
-        }
-        else if (turl[0] == '/') {
+        if (turl[0] == '/') {
             failed = -1;
             gfal2_set_error(tmp_err, gfal2_get_plugin_srm_quark(), EBADMSG, __func__,
                     "A turl can not start with /");
@@ -69,7 +62,8 @@ static int validate_turls(int n_results, gfal_srm_result** resu,
         if (!matching_protocol) {
             failed = -1;
             gfal2_set_error(tmp_err, gfal2_get_plugin_srm_quark(), EBADMSG, __func__,
-                    "The SRM endpoint returned a protocol that wasn't requested: %s");
+                    "The SRM endpoint returned a protocol that wasn't requested: %s",
+                    turl);
         }
     }
     // Didn't match, so free and set an error
@@ -112,6 +106,7 @@ int gfal_srmv2_get_global(gfal_srmv2_opt* opts, gfal_srm_params_t params, srm_co
 	if(ret < 0){
 		gfal_srm_report_error(context->errbuf, &tmp_err);
 	} else{
+	    gfal2_log(G_LOG_LEVEL_MESSAGE, "Got GET token for %s: %s", input->surls[0], preparetoget_output.token);
 		gfal_srm_convert_filestatuses_to_srm_result(preparetoget_output.filestatuses, preparetoget_output.token, ret, resu,  &tmp_err);
 	}
 
@@ -141,6 +136,7 @@ int gfal_srmv2_put_global(gfal_srmv2_opt* opts, gfal_srm_params_t params, srm_co
         gfal_srm_report_error(context->errbuf, &tmp_err);
     }
     else {
+        gfal2_log(G_LOG_LEVEL_MESSAGE, "Got PUT token for %s: %s", input->surls[0], preparetoput_output.token);
         gfal_srm_convert_filestatuses_to_srm_result(preparetoput_output.filestatuses, preparetoput_output.token, ret, resu, &tmp_err);
     }
 
@@ -172,6 +168,7 @@ int gfal_srm_getTURLS_srmv2_internal(srm_context_t context, gfal_srmv2_opt* opts
 	preparetoget_input.protocols = gfal_srm_params_get_protocols(params);
     preparetoget_input.spacetokendesc = gfal_srm_params_get_spacetoken(params);
 	preparetoget_input.surls = surls;
+
     ret = gfal_srmv2_get_global(opts, params, context, &preparetoget_input, resu, &tmp_err);
 	G_RETURN_ERR(ret, tmp_err, err);
 }
@@ -221,6 +218,7 @@ static int gfal_srm_mTURLS_internal(gfal_srmv2_opt* opts, gfal_srm_params_t para
         else
             ret = gfal_srm_putTURLS_srmv2_internal(context, opts, params, surls, resu, &tmp_err);
     }
+    gfal_srm_ifce_easy_context_release(opts, context);
 
     if (ret < 0) {
         gfal2_propagate_prefixed_error(err, tmp_err, __func__);
@@ -463,7 +461,7 @@ static int gfal_srm_putdone_srmv2_internal(srm_context_t context, char** surls,
 	putdone_input.reqtoken = (char*)token;
 	putdone_input.surls = surls;
 
-    gfal_log(GFAL_VERBOSE_TRACE, "    [gfal_srm_putdone_srmv2_internal] start srm put done on %s", surls[0]);
+    gfal2_log(G_LOG_LEVEL_DEBUG, "    [gfal_srm_putdone_srmv2_internal] start srm put done on %s", surls[0]);
     ret = gfal_srm_external_call.srm_put_done(context,&putdone_input, &statuses);
     if(ret < 0){
         gfal2_set_error(&tmp_err, gfal2_get_plugin_srm_quark(), errno, __func__,
@@ -482,12 +480,13 @@ int gfal_srm_putdone(gfal_srmv2_opt* opts , char** surls, const char* token,  GE
     GError* tmp_err = NULL;
     int ret = -1;
 
-    gfal_log(GFAL_VERBOSE_TRACE, "   -> [gfal_srm_putdone] ");
+    gfal2_log(G_LOG_LEVEL_DEBUG, "   -> [gfal_srm_putdone] ");
 
     srm_context_t context = gfal_srm_ifce_easy_context(opts, surls[0], &tmp_err);
     if (context != NULL) {
         ret = gfal_srm_putdone_srmv2_internal(context, surls, token, &tmp_err);
     }
+    gfal_srm_ifce_easy_context_release(opts, context);
 
     if (ret < 0)
         gfal2_propagate_prefixed_error(err, tmp_err, __func__);
@@ -526,14 +525,15 @@ int srm_abort_request_plugin(plugin_handle * handle , const char* surl,
     gfal_srmv2_opt* opts = (gfal_srmv2_opt*) handle;
     int ret = -1;
 
-    gfal_log(GFAL_VERBOSE_TRACE, "   -> [srm_abort_request] ");
+    gfal2_log(G_LOG_LEVEL_DEBUG, "   -> [srm_abort_request] ");
 
     srm_context_t context = gfal_srm_ifce_easy_context(opts, surl, &tmp_err);
     if (context != NULL) {
         ret = srmv2_abort_request_internal(context, surl, reqtoken, &tmp_err);
     }
+    gfal_srm_ifce_easy_context_release(opts, context);
 
-    gfal_log(GFAL_VERBOSE_TRACE, " [srm_abort_request] <-");
+    gfal2_log(G_LOG_LEVEL_DEBUG, " [srm_abort_request] <-");
 
     if (ret < 0)
         gfal2_propagate_prefixed_error(err, tmp_err, __func__);
