@@ -24,7 +24,7 @@
 gboolean srm_check_url(const char * surl);
 
 /*
- * 
+ *
  * implementation of the plugi_url_transfer_check for the srm plugin
  * Check if the srm plugin is able to handle a given type of URL.
  * 
@@ -34,4 +34,12 @@ gboolean plugin_url_check2(plugin_handle handle, gfal2_context_t context,
         const char* src, const char* dst, gfal_url2_check type );
 
 
+/**
+ * Comparing two SURLs is not a trivial strcmp, since a SURL like
+ * srm://host:port/endpoint?SFN=blah
+ * must be considered equivalent to
+ * srm://host:port/blah
+ **/
+int gfal2_srm_surl_cmp(const char* surl1, const char* surl2);
+
 #endif /* GFAL_COMMON_SRM_URL_CHECK_H */ 
